;; Generated package description from tempel.el  -*- mode: lisp-data; no-byte-compile: t -*-
(define-package "tempel" "1.9.0.20251130.84712" "Tempo templates/snippets with in-buffer field editing" '((emacs "29.1") (compat "30")) :commit "506a8d570c145f4df63a18921e34bac6bef3ebe0" :authors '(("Daniel Mendler" . "mail@daniel-mendler.de")) :maintainer '("Daniel Mendler" . "mail@daniel-mendler.de") :keywords '("abbrev" "languages" "tools" "text") :url "https://github.com/minad/tempel")
